@@ -1,20 +1,20 @@
 package WWW::GoKGS::Scraper::Top100;
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 use parent qw/WWW::GoKGS::Scraper/;
 use WWW::GoKGS::Scraper::Declare;
 
 sub base_uri { 'http://www.gokgs.com/top100.jsp' }
 
-sub _build_scraper {
+sub __build_scraper {
     my $self = shift;
 
     scraper {
         process '//table[@class="grid"]//following-sibling::tr',
                 'players[]' => scraper {
                     process '//td[1]', 'position' => 'TEXT';
-                    process '//td[2]//a', 'name' => 'TEXT';
-                    process '//td[2]//a', 'uri' => '@href';
+                    process '//td[2]/a', 'name' => 'TEXT';
+                    process '//td[2]/a', 'uri' => '@href';
                     process '//td[3]', 'rank' => 'TEXT'; };
     };
 }
@@ -43,13 +43,10 @@ This class inherits from L<WWW::GoKGS::Scraper>.
 
 =item $uri = $class->base_uri
 
-Returns a URI string. Defaults to C<http://www.gokgs.com/top100.jsp>.
+  # => "http://www.gokgs.com/top100.jsp"
 
 =item $URI = $class->build_uri
 
-Returns a L<URI> object created from C<base_uri>.
-
-  my $uri = WWW::GoKGS::Scraper::Top100->build_uri;
   # => URI->new( "http://www.gokgs.com/top100.jsp" )
 
 =back
